# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Landmark(object):
    """
    The landmark on the face.
    """

    #: A constant which can be used with the type property of a Landmark.
    #: This constant has a value of "LEFT_EYE"
    TYPE_LEFT_EYE = "LEFT_EYE"

    #: A constant which can be used with the type property of a Landmark.
    #: This constant has a value of "RIGHT_EYE"
    TYPE_RIGHT_EYE = "RIGHT_EYE"

    #: A constant which can be used with the type property of a Landmark.
    #: This constant has a value of "NOSE_TIP"
    TYPE_NOSE_TIP = "NOSE_TIP"

    #: A constant which can be used with the type property of a Landmark.
    #: This constant has a value of "LEFT_EDGE_OF_MOUTH"
    TYPE_LEFT_EDGE_OF_MOUTH = "LEFT_EDGE_OF_MOUTH"

    #: A constant which can be used with the type property of a Landmark.
    #: This constant has a value of "RIGHT_EDGE_OF_MOUTH"
    TYPE_RIGHT_EDGE_OF_MOUTH = "RIGHT_EDGE_OF_MOUTH"

    def __init__(self, **kwargs):
        """
        Initializes a new Landmark object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this Landmark.
            Allowed values for this property are: "LEFT_EYE", "RIGHT_EYE", "NOSE_TIP", "LEFT_EDGE_OF_MOUTH", "RIGHT_EDGE_OF_MOUTH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param x:
            The value to assign to the x property of this Landmark.
        :type x: float

        :param y:
            The value to assign to the y property of this Landmark.
        :type y: float

        """
        self.swagger_types = {
            'type': 'str',
            'x': 'float',
            'y': 'float'
        }
        self.attribute_map = {
            'type': 'type',
            'x': 'x',
            'y': 'y'
        }
        self._type = None
        self._x = None
        self._y = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this Landmark.
        The face landmark type

        Allowed values for this property are: "LEFT_EYE", "RIGHT_EYE", "NOSE_TIP", "LEFT_EDGE_OF_MOUTH", "RIGHT_EDGE_OF_MOUTH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this Landmark.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Landmark.
        The face landmark type


        :param type: The type of this Landmark.
        :type: str
        """
        allowed_values = ["LEFT_EYE", "RIGHT_EYE", "NOSE_TIP", "LEFT_EDGE_OF_MOUTH", "RIGHT_EDGE_OF_MOUTH"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def x(self):
        """
        **[Required]** Gets the x of this Landmark.
        The X-axis normalized coordinate.


        :return: The x of this Landmark.
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """
        Sets the x of this Landmark.
        The X-axis normalized coordinate.


        :param x: The x of this Landmark.
        :type: float
        """
        self._x = x

    @property
    def y(self):
        """
        **[Required]** Gets the y of this Landmark.
        The Y-axis normalized coordinate.


        :return: The y of this Landmark.
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """
        Sets the y of this Landmark.
        The Y-axis normalized coordinate.


        :param y: The y of this Landmark.
        :type: float
        """
        self._y = y

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateStreamJobDetails(object):
    """
    The information needed to update streamjob
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateStreamJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stream_source_id:
            The value to assign to the stream_source_id property of this UpdateStreamJobDetails.
        :type stream_source_id: str

        :param features:
            The value to assign to the features property of this UpdateStreamJobDetails.
        :type features: list[oci.ai_vision.models.VideoStreamFeature]

        :param stream_output_location:
            The value to assign to the stream_output_location property of this UpdateStreamJobDetails.
        :type stream_output_location: oci.ai_vision.models.StreamOutputLocation

        :param display_name:
            The value to assign to the display_name property of this UpdateStreamJobDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateStreamJobDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateStreamJobDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'stream_source_id': 'str',
            'features': 'list[VideoStreamFeature]',
            'stream_output_location': 'StreamOutputLocation',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'stream_source_id': 'streamSourceId',
            'features': 'features',
            'stream_output_location': 'streamOutputLocation',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }
        self._stream_source_id = None
        self._features = None
        self._stream_output_location = None
        self._display_name = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def stream_source_id(self):
        """
        Gets the stream_source_id of this UpdateStreamJobDetails.
        `OCID`__ of streamSource

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stream_source_id of this UpdateStreamJobDetails.
        :rtype: str
        """
        return self._stream_source_id

    @stream_source_id.setter
    def stream_source_id(self, stream_source_id):
        """
        Sets the stream_source_id of this UpdateStreamJobDetails.
        `OCID`__ of streamSource

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stream_source_id: The stream_source_id of this UpdateStreamJobDetails.
        :type: str
        """
        self._stream_source_id = stream_source_id

    @property
    def features(self):
        """
        Gets the features of this UpdateStreamJobDetails.
        List of stream analysis features.


        :return: The features of this UpdateStreamJobDetails.
        :rtype: list[oci.ai_vision.models.VideoStreamFeature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this UpdateStreamJobDetails.
        List of stream analysis features.


        :param features: The features of this UpdateStreamJobDetails.
        :type: list[oci.ai_vision.models.VideoStreamFeature]
        """
        self._features = features

    @property
    def stream_output_location(self):
        """
        Gets the stream_output_location of this UpdateStreamJobDetails.

        :return: The stream_output_location of this UpdateStreamJobDetails.
        :rtype: oci.ai_vision.models.StreamOutputLocation
        """
        return self._stream_output_location

    @stream_output_location.setter
    def stream_output_location(self, stream_output_location):
        """
        Sets the stream_output_location of this UpdateStreamJobDetails.

        :param stream_output_location: The stream_output_location of this UpdateStreamJobDetails.
        :type: oci.ai_vision.models.StreamOutputLocation
        """
        self._stream_output_location = stream_output_location

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateStreamJobDetails.
        Stream job display name.


        :return: The display_name of this UpdateStreamJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateStreamJobDetails.
        Stream job display name.


        :param display_name: The display_name of this UpdateStreamJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateStreamJobDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateStreamJobDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateStreamJobDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateStreamJobDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateStreamJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateStreamJobDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateStreamJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateStreamJobDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .stream_network_access_details import StreamNetworkAccessDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateStreamNetworkAccessDetails(StreamNetworkAccessDetails):
    """
    Details of private endpoint to connect to stream
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateStreamNetworkAccessDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.PrivateStreamNetworkAccessDetails.stream_access_type` attribute
        of this class is ``PRIVATE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stream_access_type:
            The value to assign to the stream_access_type property of this PrivateStreamNetworkAccessDetails.
            Allowed values for this property are: "PRIVATE"
        :type stream_access_type: str

        :param private_endpoint_id:
            The value to assign to the private_endpoint_id property of this PrivateStreamNetworkAccessDetails.
        :type private_endpoint_id: str

        """
        self.swagger_types = {
            'stream_access_type': 'str',
            'private_endpoint_id': 'str'
        }
        self.attribute_map = {
            'stream_access_type': 'streamAccessType',
            'private_endpoint_id': 'privateEndpointId'
        }
        self._stream_access_type = None
        self._private_endpoint_id = None
        self._stream_access_type = 'PRIVATE'

    @property
    def private_endpoint_id(self):
        """
        **[Required]** Gets the private_endpoint_id of this PrivateStreamNetworkAccessDetails.
        `OCID`__ of the private Endpoint

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The private_endpoint_id of this PrivateStreamNetworkAccessDetails.
        :rtype: str
        """
        return self._private_endpoint_id

    @private_endpoint_id.setter
    def private_endpoint_id(self, private_endpoint_id):
        """
        Sets the private_endpoint_id of this PrivateStreamNetworkAccessDetails.
        `OCID`__ of the private Endpoint

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param private_endpoint_id: The private_endpoint_id of this PrivateStreamNetworkAccessDetails.
        :type: str
        """
        self._private_endpoint_id = private_endpoint_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .image_details import ImageDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageImageDetails(ImageDetails):
    """
    The image residing in OCI Object Storage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageImageDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.ObjectStorageImageDetails.source` attribute
        of this class is ``OBJECT_STORAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this ObjectStorageImageDetails.
            Allowed values for this property are: "INLINE", "OBJECT_STORAGE"
        :type source: str

        :param namespace_name:
            The value to assign to the namespace_name property of this ObjectStorageImageDetails.
        :type namespace_name: str

        :param bucket_name:
            The value to assign to the bucket_name property of this ObjectStorageImageDetails.
        :type bucket_name: str

        :param object_name:
            The value to assign to the object_name property of this ObjectStorageImageDetails.
        :type object_name: str

        """
        self.swagger_types = {
            'source': 'str',
            'namespace_name': 'str',
            'bucket_name': 'str',
            'object_name': 'str'
        }
        self.attribute_map = {
            'source': 'source',
            'namespace_name': 'namespaceName',
            'bucket_name': 'bucketName',
            'object_name': 'objectName'
        }
        self._source = None
        self._namespace_name = None
        self._bucket_name = None
        self._object_name = None
        self._source = 'OBJECT_STORAGE'

    @property
    def namespace_name(self):
        """
        **[Required]** Gets the namespace_name of this ObjectStorageImageDetails.
        The Object Storage namespace.


        :return: The namespace_name of this ObjectStorageImageDetails.
        :rtype: str
        """
        return self._namespace_name

    @namespace_name.setter
    def namespace_name(self, namespace_name):
        """
        Sets the namespace_name of this ObjectStorageImageDetails.
        The Object Storage namespace.


        :param namespace_name: The namespace_name of this ObjectStorageImageDetails.
        :type: str
        """
        self._namespace_name = namespace_name

    @property
    def bucket_name(self):
        """
        **[Required]** Gets the bucket_name of this ObjectStorageImageDetails.
        The Object Storage bucket name.


        :return: The bucket_name of this ObjectStorageImageDetails.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this ObjectStorageImageDetails.
        The Object Storage bucket name.


        :param bucket_name: The bucket_name of this ObjectStorageImageDetails.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this ObjectStorageImageDetails.
        The Object Storage object name.


        :return: The object_name of this ObjectStorageImageDetails.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this ObjectStorageImageDetails.
        The Object Storage object name.


        :param object_name: The object_name of this ObjectStorageImageDetails.
        :type: str
        """
        self._object_name = object_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DetectedLanguage(object):
    """
    The language detected in a document.
    """

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "ENG"
    LANGUAGE_CODE_ENG = "ENG"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "CES"
    LANGUAGE_CODE_CES = "CES"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "DAN"
    LANGUAGE_CODE_DAN = "DAN"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "NLD"
    LANGUAGE_CODE_NLD = "NLD"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "FIN"
    LANGUAGE_CODE_FIN = "FIN"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "FRA"
    LANGUAGE_CODE_FRA = "FRA"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "DEU"
    LANGUAGE_CODE_DEU = "DEU"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "ELL"
    LANGUAGE_CODE_ELL = "ELL"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "HUN"
    LANGUAGE_CODE_HUN = "HUN"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "ITA"
    LANGUAGE_CODE_ITA = "ITA"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "NOR"
    LANGUAGE_CODE_NOR = "NOR"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "POL"
    LANGUAGE_CODE_POL = "POL"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "POR"
    LANGUAGE_CODE_POR = "POR"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "RON"
    LANGUAGE_CODE_RON = "RON"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "RUS"
    LANGUAGE_CODE_RUS = "RUS"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "SLK"
    LANGUAGE_CODE_SLK = "SLK"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "SPA"
    LANGUAGE_CODE_SPA = "SPA"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "SWE"
    LANGUAGE_CODE_SWE = "SWE"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "TUR"
    LANGUAGE_CODE_TUR = "TUR"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "ARA"
    LANGUAGE_CODE_ARA = "ARA"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "CHI_SIM"
    LANGUAGE_CODE_CHI_SIM = "CHI_SIM"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "HIN"
    LANGUAGE_CODE_HIN = "HIN"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "JPN"
    LANGUAGE_CODE_JPN = "JPN"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "KOR"
    LANGUAGE_CODE_KOR = "KOR"

    #: A constant which can be used with the language_code property of a DetectedLanguage.
    #: This constant has a value of "OTHERS"
    LANGUAGE_CODE_OTHERS = "OTHERS"

    def __init__(self, **kwargs):
        """
        Initializes a new DetectedLanguage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param language_code:
            The value to assign to the language_code property of this DetectedLanguage.
            Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type language_code: str

        :param confidence:
            The value to assign to the confidence property of this DetectedLanguage.
        :type confidence: float

        """
        self.swagger_types = {
            'language_code': 'str',
            'confidence': 'float'
        }
        self.attribute_map = {
            'language_code': 'languageCode',
            'confidence': 'confidence'
        }
        self._language_code = None
        self._confidence = None

    @property
    def language_code(self):
        """
        **[Required]** Gets the language_code of this DetectedLanguage.
        The language of the document, abbreviated according to ISO 639-2.

        Allowed values for this property are: "ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The language_code of this DetectedLanguage.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this DetectedLanguage.
        The language of the document, abbreviated according to ISO 639-2.


        :param language_code: The language_code of this DetectedLanguage.
        :type: str
        """
        allowed_values = ["ENG", "CES", "DAN", "NLD", "FIN", "FRA", "DEU", "ELL", "HUN", "ITA", "NOR", "POL", "POR", "RON", "RUS", "SLK", "SPA", "SWE", "TUR", "ARA", "CHI_SIM", "HIN", "JPN", "KOR", "OTHERS"]
        if not value_allowed_none_or_none_sentinel(language_code, allowed_values):
            language_code = 'UNKNOWN_ENUM_VALUE'
        self._language_code = language_code

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this DetectedLanguage.
        The confidence score between 0 and 1.


        :return: The confidence of this DetectedLanguage.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this DetectedLanguage.
        The confidence score between 0 and 1.


        :param confidence: The confidence of this DetectedLanguage.
        :type: float
        """
        self._confidence = confidence

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .image_feature import ImageFeature
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FaceEmbeddingFeature(ImageFeature):
    """
    The face embedding parameters
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FaceEmbeddingFeature object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.FaceEmbeddingFeature.feature_type` attribute
        of this class is ``FACE_EMBEDDING`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this FaceEmbeddingFeature.
            Allowed values for this property are: "IMAGE_CLASSIFICATION", "OBJECT_DETECTION", "TEXT_DETECTION", "FACE_DETECTION", "FACE_EMBEDDING"
        :type feature_type: str

        :param max_results:
            The value to assign to the max_results property of this FaceEmbeddingFeature.
        :type max_results: int

        :param should_return_landmarks:
            The value to assign to the should_return_landmarks property of this FaceEmbeddingFeature.
        :type should_return_landmarks: bool

        """
        self.swagger_types = {
            'feature_type': 'str',
            'max_results': 'int',
            'should_return_landmarks': 'bool'
        }
        self.attribute_map = {
            'feature_type': 'featureType',
            'max_results': 'maxResults',
            'should_return_landmarks': 'shouldReturnLandmarks'
        }
        self._feature_type = None
        self._max_results = None
        self._should_return_landmarks = None
        self._feature_type = 'FACE_EMBEDDING'

    @property
    def max_results(self):
        """
        Gets the max_results of this FaceEmbeddingFeature.
        The maximum number of results to return.


        :return: The max_results of this FaceEmbeddingFeature.
        :rtype: int
        """
        return self._max_results

    @max_results.setter
    def max_results(self, max_results):
        """
        Sets the max_results of this FaceEmbeddingFeature.
        The maximum number of results to return.


        :param max_results: The max_results of this FaceEmbeddingFeature.
        :type: int
        """
        self._max_results = max_results

    @property
    def should_return_landmarks(self):
        """
        Gets the should_return_landmarks of this FaceEmbeddingFeature.
        Whether or not return face landmarks.


        :return: The should_return_landmarks of this FaceEmbeddingFeature.
        :rtype: bool
        """
        return self._should_return_landmarks

    @should_return_landmarks.setter
    def should_return_landmarks(self, should_return_landmarks):
        """
        Sets the should_return_landmarks of this FaceEmbeddingFeature.
        Whether or not return face landmarks.


        :param should_return_landmarks: The should_return_landmarks of this FaceEmbeddingFeature.
        :type: bool
        """
        self._should_return_landmarks = should_return_landmarks

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BoundingPolygon(object):
    """
    The object-bounding polygon box.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BoundingPolygon object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param normalized_vertices:
            The value to assign to the normalized_vertices property of this BoundingPolygon.
        :type normalized_vertices: list[oci.ai_vision.models.NormalizedVertex]

        """
        self.swagger_types = {
            'normalized_vertices': 'list[NormalizedVertex]'
        }
        self.attribute_map = {
            'normalized_vertices': 'normalizedVertices'
        }
        self._normalized_vertices = None

    @property
    def normalized_vertices(self):
        """
        **[Required]** Gets the normalized_vertices of this BoundingPolygon.
        An array of normalized points defining the polygon's perimeter, with an implicit segment between subsequent points and between the first and last point.
        Rectangles are defined with four points. For example, `[{\"x\": 0, \"y\": 0}, {\"x\": 1, \"y\": 0}, {\"x\": 1, \"y\": 0.5}, {\"x\": 0, \"y\": 0.5}]` represents the top half of an image.


        :return: The normalized_vertices of this BoundingPolygon.
        :rtype: list[oci.ai_vision.models.NormalizedVertex]
        """
        return self._normalized_vertices

    @normalized_vertices.setter
    def normalized_vertices(self, normalized_vertices):
        """
        Sets the normalized_vertices of this BoundingPolygon.
        An array of normalized points defining the polygon's perimeter, with an implicit segment between subsequent points and between the first and last point.
        Rectangles are defined with four points. For example, `[{\"x\": 0, \"y\": 0}, {\"x\": 1, \"y\": 0}, {\"x\": 1, \"y\": 0.5}, {\"x\": 0, \"y\": 0.5}]` represents the top half of an image.


        :param normalized_vertices: The normalized_vertices of this BoundingPolygon.
        :type: list[oci.ai_vision.models.NormalizedVertex]
        """
        self._normalized_vertices = normalized_vertices

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Face(object):
    """
    The detected face.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Face object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param confidence:
            The value to assign to the confidence property of this Face.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this Face.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        :param quality_score:
            The value to assign to the quality_score property of this Face.
        :type quality_score: float

        :param landmarks:
            The value to assign to the landmarks property of this Face.
        :type landmarks: list[oci.ai_vision.models.Landmark]

        :param embeddings:
            The value to assign to the embeddings property of this Face.
        :type embeddings: list[float]

        """
        self.swagger_types = {
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon',
            'quality_score': 'float',
            'landmarks': 'list[Landmark]',
            'embeddings': 'list[float]'
        }
        self.attribute_map = {
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon',
            'quality_score': 'qualityScore',
            'landmarks': 'landmarks',
            'embeddings': 'embeddings'
        }
        self._confidence = None
        self._bounding_polygon = None
        self._quality_score = None
        self._landmarks = None
        self._embeddings = None

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this Face.
        The confidence score, between 0 and 1.


        :return: The confidence of this Face.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this Face.
        The confidence score, between 0 and 1.


        :param confidence: The confidence of this Face.
        :type: float
        """
        self._confidence = confidence

    @property
    def bounding_polygon(self):
        """
        **[Required]** Gets the bounding_polygon of this Face.

        :return: The bounding_polygon of this Face.
        :rtype: oci.ai_vision.models.BoundingPolygon
        """
        return self._bounding_polygon

    @bounding_polygon.setter
    def bounding_polygon(self, bounding_polygon):
        """
        Sets the bounding_polygon of this Face.

        :param bounding_polygon: The bounding_polygon of this Face.
        :type: oci.ai_vision.models.BoundingPolygon
        """
        self._bounding_polygon = bounding_polygon

    @property
    def quality_score(self):
        """
        **[Required]** Gets the quality_score of this Face.
        The quality score of the face detected, between 0 and 1.


        :return: The quality_score of this Face.
        :rtype: float
        """
        return self._quality_score

    @quality_score.setter
    def quality_score(self, quality_score):
        """
        Sets the quality_score of this Face.
        The quality score of the face detected, between 0 and 1.


        :param quality_score: The quality_score of this Face.
        :type: float
        """
        self._quality_score = quality_score

    @property
    def landmarks(self):
        """
        Gets the landmarks of this Face.
        A point of interest within a face.


        :return: The landmarks of this Face.
        :rtype: list[oci.ai_vision.models.Landmark]
        """
        return self._landmarks

    @landmarks.setter
    def landmarks(self, landmarks):
        """
        Sets the landmarks of this Face.
        A point of interest within a face.


        :param landmarks: The landmarks of this Face.
        :type: list[oci.ai_vision.models.Landmark]
        """
        self._landmarks = landmarks

    @property
    def embeddings(self):
        """
        Gets the embeddings of this Face.
        The facial feature vectors of detected faces


        :return: The embeddings of this Face.
        :rtype: list[float]
        """
        return self._embeddings

    @embeddings.setter
    def embeddings(self, embeddings):
        """
        Sets the embeddings of this Face.
        The facial feature vectors of detected faces


        :param embeddings: The embeddings of this Face.
        :type: list[float]
        """
        self._embeddings = embeddings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class AIServiceVisionClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.ai_vision.AIServiceVisionClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new AIServiceVisionClientCompositeOperations object

        :param AIServiceVisionClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_stream_group_compartment_and_wait_for_state(self, stream_group_id, change_stream_group_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_group_compartment` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_group_id: (required)
            StreamGroup Id.

        :param oci.ai_vision.models.ChangeStreamGroupCompartmentDetails change_stream_group_compartment_details: (required)
            The details of the move.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_group_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_stream_group_compartment(stream_group_id, change_stream_group_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_stream_job_compartment_and_wait_for_state(self, stream_job_id, change_stream_job_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_job_compartment` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_job_id: (required)
            Stream job id.

        :param oci.ai_vision.models.ChangeStreamJobCompartmentDetails change_stream_job_compartment_details: (required)
            The details of the move.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_job_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_stream_job_compartment(stream_job_id, change_stream_job_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_stream_source_compartment_and_wait_for_state(self, stream_source_id, change_stream_source_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_source_compartment` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_source_id: (required)
            StreamSource Id.

        :param oci.ai_vision.models.ChangeStreamSourceCompartmentDetails change_stream_source_compartment_details: (required)
            The details of the move.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.change_stream_source_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_stream_source_compartment(stream_source_id, change_stream_source_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_document_job_and_wait_for_state(self, create_document_job_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_document_job` and waits for the :py:class:`~oci.ai_vision.models.DocumentJob` acted upon
        to enter the given state(s).

        :param oci.ai_vision.models.CreateDocumentJobDetails create_document_job_details: (required)
            The details of the batch document analysis.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.DocumentJob.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_document_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_document_job(create_document_job_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        document_job_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_document_job(document_job_id),  # noqa: F821
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except (NameError, TypeError) as e:
            if not e.args:
                e.args = ('',)
            e.args = e.args + ('This composite operation is currently not supported in the SDK. Please use the operation from the service client and use waiters as an alternative. For more information on waiters, visit: "https://docs.oracle.com/en-us/iaas/tools/python/latest/api/waiters.html"', )
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_image_job_and_wait_for_state(self, create_image_job_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_image_job` and waits for the :py:class:`~oci.ai_vision.models.ImageJob` acted upon
        to enter the given state(s).

        :param oci.ai_vision.models.CreateImageJobDetails create_image_job_details: (required)
            The details of the batch image analysis.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.ImageJob.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_image_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_image_job(create_image_job_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        image_job_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_image_job(image_job_id),  # noqa: F821
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except (NameError, TypeError) as e:
            if not e.args:
                e.args = ('',)
            e.args = e.args + ('This composite operation is currently not supported in the SDK. Please use the operation from the service client and use waiters as an alternative. For more information on waiters, visit: "https://docs.oracle.com/en-us/iaas/tools/python/latest/api/waiters.html"', )
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_model_and_wait_for_state(self, create_model_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_model` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateModelDetails create_model_details: (required)
            The metadata about the new model.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_model(create_model_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_project_and_wait_for_state(self, create_project_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_project` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateProjectDetails create_project_details: (required)
            The new Project's details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_project(create_project_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_stream_group_and_wait_for_state(self, create_stream_group_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_group` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateStreamGroupDetails create_stream_group_details: (required)
            Details about the streamGroup

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_group`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_stream_group(create_stream_group_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_stream_job_and_wait_for_state(self, create_stream_job_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_job` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateStreamJobDetails create_stream_job_details: (required)
            Details about the stream analysis.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_stream_job(create_stream_job_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_stream_source_and_wait_for_state(self, create_stream_source_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_source` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateStreamSourceDetails create_stream_source_details: (required)
            Details about the StreamSource

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_stream_source`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_stream_source(create_stream_source_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_video_job_and_wait_for_state(self, create_video_job_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_video_job` and waits for the :py:class:`~oci.ai_vision.models.VideoJob` acted upon
        to enter the given state(s).

        :param oci.ai_vision.models.CreateVideoJobDetails create_video_job_details: (required)
            Details about the video analysis.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.VideoJob.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_video_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_video_job(create_video_job_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        video_job_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_video_job(video_job_id),  # noqa: F821
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except (NameError, TypeError) as e:
            if not e.args:
                e.args = ('',)
            e.args = e.args + ('This composite operation is currently not supported in the SDK. Please use the operation from the service client and use waiters as an alternative. For more information on waiters, visit: "https://docs.oracle.com/en-us/iaas/tools/python/latest/api/waiters.html"', )
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_vision_private_endpoint_and_wait_for_state(self, create_vision_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.create_vision_private_endpoint` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.CreateVisionPrivateEndpointDetails create_vision_private_endpoint_details: (required)
            The new VisionPrivateEndpoint's details.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.create_vision_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_vision_private_endpoint(create_vision_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_model_and_wait_for_state(self, model_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_model` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str model_id: (required)
            A unique model identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_model(model_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_project_and_wait_for_state(self, project_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_project` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str project_id: (required)
            A unique project identifier.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_project(project_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_stream_group_and_wait_for_state(self, stream_group_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_group` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_group_id: (required)
            StreamGroup Id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_group`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_stream_group(stream_group_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_stream_job_and_wait_for_state(self, stream_job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_job` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_job_id: (required)
            Stream job id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_stream_job(stream_job_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_stream_source_and_wait_for_state(self, stream_source_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_source` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_source_id: (required)
            StreamSource Id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_stream_source`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_stream_source(stream_source_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_vision_private_endpoint_and_wait_for_state(self, vision_private_endpoint_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_vision_private_endpoint` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str vision_private_endpoint_id: (required)
            Vision private endpoint Id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.delete_vision_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_vision_private_endpoint(vision_private_endpoint_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def start_stream_job_and_wait_for_state(self, stream_job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.start_stream_job` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_job_id: (required)
            Stream job id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.start_stream_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.start_stream_job(stream_job_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def stop_stream_job_and_wait_for_state(self, stream_job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.stop_stream_job` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_job_id: (required)
            Stream job id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.stop_stream_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.stop_stream_job(stream_job_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_model_and_wait_for_state(self, model_id, update_model_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_model` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str model_id: (required)
            A unique model identifier.

        :param oci.ai_vision.models.UpdateModelDetails update_model_details: (required)
            The model metadata to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_model`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_model(model_id, update_model_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_project_and_wait_for_state(self, project_id, update_project_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_project` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str project_id: (required)
            A unique project identifier.

        :param oci.ai_vision.models.UpdateProjectDetails update_project_details: (required)
            The project metadata to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_project`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_project(project_id, update_project_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_stream_group_and_wait_for_state(self, stream_group_id, update_stream_group_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_group` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_group_id: (required)
            StreamGroup Id.

        :param oci.ai_vision.models.UpdateStreamGroupDetails update_stream_group_details: (required)
            Details about the streamGroup

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_group`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_stream_group(stream_group_id, update_stream_group_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_stream_job_and_wait_for_state(self, update_stream_job_details, stream_job_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_job` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param oci.ai_vision.models.UpdateStreamJobDetails update_stream_job_details: (required)
            Details about the stream analysis.

        :param str stream_job_id: (required)
            Stream job id.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_job`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_stream_job(update_stream_job_details, stream_job_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_stream_source_and_wait_for_state(self, stream_source_id, update_stream_source_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_source` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str stream_source_id: (required)
            StreamSource Id.

        :param oci.ai_vision.models.UpdateStreamSourceDetails update_stream_source_details: (required)
            Details about the StreamSource

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_stream_source`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_stream_source(stream_source_id, update_stream_source_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_vision_private_endpoint_and_wait_for_state(self, vision_private_endpoint_id, update_vision_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.ai_vision.AIServiceVisionClient.update_vision_private_endpoint` and waits for the :py:class:`~oci.ai_vision.models.WorkRequest`
        to enter the given state(s).

        :param str vision_private_endpoint_id: (required)
            Vision private endpoint Id.

        :param oci.ai_vision.models.UpdateVisionPrivateEndpointDetails update_vision_private_endpoint_details: (required)
            The visionPrivateEndpoint metadata to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.ai_vision.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.ai_vision.AIServiceVisionClient.update_vision_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_vision_private_endpoint(vision_private_endpoint_id, update_vision_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result
        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        if 'opc-work-request-id' not in operation_result.headers:
            return operation_result
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateModelDetails(object):
    """
    The information needed to create a new model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateModelDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateModelDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateModelDetails.
        :type description: str

        :param model_version:
            The value to assign to the model_version property of this CreateModelDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this CreateModelDetails.
        :type model_type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateModelDetails.
        :type compartment_id: str

        :param is_quick_mode:
            The value to assign to the is_quick_mode property of this CreateModelDetails.
        :type is_quick_mode: bool

        :param max_training_duration_in_hours:
            The value to assign to the max_training_duration_in_hours property of this CreateModelDetails.
        :type max_training_duration_in_hours: float

        :param training_dataset:
            The value to assign to the training_dataset property of this CreateModelDetails.
        :type training_dataset: oci.ai_vision.models.Dataset

        :param testing_dataset:
            The value to assign to the testing_dataset property of this CreateModelDetails.
        :type testing_dataset: oci.ai_vision.models.Dataset

        :param validation_dataset:
            The value to assign to the validation_dataset property of this CreateModelDetails.
        :type validation_dataset: oci.ai_vision.models.Dataset

        :param project_id:
            The value to assign to the project_id property of this CreateModelDetails.
        :type project_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateModelDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateModelDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'model_version': 'str',
            'model_type': 'str',
            'compartment_id': 'str',
            'is_quick_mode': 'bool',
            'max_training_duration_in_hours': 'float',
            'training_dataset': 'Dataset',
            'testing_dataset': 'Dataset',
            'validation_dataset': 'Dataset',
            'project_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }
        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'compartment_id': 'compartmentId',
            'is_quick_mode': 'isQuickMode',
            'max_training_duration_in_hours': 'maxTrainingDurationInHours',
            'training_dataset': 'trainingDataset',
            'testing_dataset': 'testingDataset',
            'validation_dataset': 'validationDataset',
            'project_id': 'projectId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }
        self._display_name = None
        self._description = None
        self._model_version = None
        self._model_type = None
        self._compartment_id = None
        self._is_quick_mode = None
        self._max_training_duration_in_hours = None
        self._training_dataset = None
        self._testing_dataset = None
        self._validation_dataset = None
        self._project_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateModelDetails.
        A human-friendly name for the model, which can be changed.


        :return: The display_name of this CreateModelDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateModelDetails.
        A human-friendly name for the model, which can be changed.


        :param display_name: The display_name of this CreateModelDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateModelDetails.
        An optional description of the model.


        :return: The description of this CreateModelDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateModelDetails.
        An optional description of the model.


        :param description: The description of this CreateModelDetails.
        :type: str
        """
        self._description = description

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateModelDetails.
        The model version


        :return: The model_version of this CreateModelDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateModelDetails.
        The model version


        :param model_version: The model_version of this CreateModelDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this CreateModelDetails.
        Which type of Vision model this is.


        :return: The model_type of this CreateModelDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this CreateModelDetails.
        Which type of Vision model this is.


        :param model_type: The model_type of this CreateModelDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateModelDetails.
        The compartment identifier.


        :return: The compartment_id of this CreateModelDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateModelDetails.
        The compartment identifier.


        :param compartment_id: The compartment_id of this CreateModelDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_quick_mode(self):
        """
        Gets the is_quick_mode of this CreateModelDetails.
        Set to true when experimenting with a new model type or dataset, so the model training is quick, with a predefined low number of passes through the training data.


        :return: The is_quick_mode of this CreateModelDetails.
        :rtype: bool
        """
        return self._is_quick_mode

    @is_quick_mode.setter
    def is_quick_mode(self, is_quick_mode):
        """
        Sets the is_quick_mode of this CreateModelDetails.
        Set to true when experimenting with a new model type or dataset, so the model training is quick, with a predefined low number of passes through the training data.


        :param is_quick_mode: The is_quick_mode of this CreateModelDetails.
        :type: bool
        """
        self._is_quick_mode = is_quick_mode

    @property
    def max_training_duration_in_hours(self):
        """
        Gets the max_training_duration_in_hours of this CreateModelDetails.
        The maximum model training duration in hours, expressed as a decimal fraction.


        :return: The max_training_duration_in_hours of this CreateModelDetails.
        :rtype: float
        """
        return self._max_training_duration_in_hours

    @max_training_duration_in_hours.setter
    def max_training_duration_in_hours(self, max_training_duration_in_hours):
        """
        Sets the max_training_duration_in_hours of this CreateModelDetails.
        The maximum model training duration in hours, expressed as a decimal fraction.


        :param max_training_duration_in_hours: The max_training_duration_in_hours of this CreateModelDetails.
        :type: float
        """
        self._max_training_duration_in_hours = max_training_duration_in_hours

    @property
    def training_dataset(self):
        """
        **[Required]** Gets the training_dataset of this CreateModelDetails.

        :return: The training_dataset of this CreateModelDetails.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._training_dataset

    @training_dataset.setter
    def training_dataset(self, training_dataset):
        """
        Sets the training_dataset of this CreateModelDetails.

        :param training_dataset: The training_dataset of this CreateModelDetails.
        :type: oci.ai_vision.models.Dataset
        """
        self._training_dataset = training_dataset

    @property
    def testing_dataset(self):
        """
        Gets the testing_dataset of this CreateModelDetails.

        :return: The testing_dataset of this CreateModelDetails.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._testing_dataset

    @testing_dataset.setter
    def testing_dataset(self, testing_dataset):
        """
        Sets the testing_dataset of this CreateModelDetails.

        :param testing_dataset: The testing_dataset of this CreateModelDetails.
        :type: oci.ai_vision.models.Dataset
        """
        self._testing_dataset = testing_dataset

    @property
    def validation_dataset(self):
        """
        Gets the validation_dataset of this CreateModelDetails.

        :return: The validation_dataset of this CreateModelDetails.
        :rtype: oci.ai_vision.models.Dataset
        """
        return self._validation_dataset

    @validation_dataset.setter
    def validation_dataset(self, validation_dataset):
        """
        Sets the validation_dataset of this CreateModelDetails.

        :param validation_dataset: The validation_dataset of this CreateModelDetails.
        :type: oci.ai_vision.models.Dataset
        """
        self._validation_dataset = validation_dataset

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this CreateModelDetails.
        The `OCID`__ of the project that contains the model.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The project_id of this CreateModelDetails.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this CreateModelDetails.
        The `OCID`__ of the project that contains the model.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param project_id: The project_id of this CreateModelDetails.
        :type: str
        """
        self._project_id = project_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateModelDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateModelDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateModelDetails.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateModelDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateModelDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateModelDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateModelDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateModelDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImageDetails(object):
    """
    The details of an image to analyze.
    """

    #: A constant which can be used with the source property of a ImageDetails.
    #: This constant has a value of "INLINE"
    SOURCE_INLINE = "INLINE"

    #: A constant which can be used with the source property of a ImageDetails.
    #: This constant has a value of "OBJECT_STORAGE"
    SOURCE_OBJECT_STORAGE = "OBJECT_STORAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new ImageDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.ai_vision.models.ObjectStorageImageDetails`
        * :class:`~oci.ai_vision.models.InlineImageDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this ImageDetails.
            Allowed values for this property are: "INLINE", "OBJECT_STORAGE"
        :type source: str

        """
        self.swagger_types = {
            'source': 'str'
        }
        self.attribute_map = {
            'source': 'source'
        }
        self._source = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['source']

        if type == 'OBJECT_STORAGE':
            return 'ObjectStorageImageDetails'

        if type == 'INLINE':
            return 'InlineImageDetails'
        else:
            return 'ImageDetails'

    @property
    def source(self):
        """
        **[Required]** Gets the source of this ImageDetails.
        The location of the image data.
        The allowed values are:
        - `INLINE`: The data is included directly in the request payload.
        - `OBJECT_STORAGE`: The image is in OCI Object Storage.

        Allowed values for this property are: "INLINE", "OBJECT_STORAGE"


        :return: The source of this ImageDetails.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this ImageDetails.
        The location of the image data.
        The allowed values are:
        - `INLINE`: The data is included directly in the request payload.
        - `OBJECT_STORAGE`: The image is in OCI Object Storage.


        :param source: The source of this ImageDetails.
        :type: str
        """
        allowed_values = ["INLINE", "OBJECT_STORAGE"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            raise ValueError(
                f"Invalid value for `source`, must be None or one of {allowed_values}"
            )
        self._source = source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .stream_source_details import StreamSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RtspSourceDetails(StreamSourceDetails):
    """
    Details of RtspDevice
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RtspSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.RtspSourceDetails.source_type` attribute
        of this class is ``RTSP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stream_network_access_details:
            The value to assign to the stream_network_access_details property of this RtspSourceDetails.
        :type stream_network_access_details: oci.ai_vision.models.StreamNetworkAccessDetails

        :param source_type:
            The value to assign to the source_type property of this RtspSourceDetails.
            Allowed values for this property are: "RTSP"
        :type source_type: str

        :param secret_id:
            The value to assign to the secret_id property of this RtspSourceDetails.
        :type secret_id: str

        :param camera_url:
            The value to assign to the camera_url property of this RtspSourceDetails.
        :type camera_url: str

        """
        self.swagger_types = {
            'stream_network_access_details': 'StreamNetworkAccessDetails',
            'source_type': 'str',
            'secret_id': 'str',
            'camera_url': 'str'
        }
        self.attribute_map = {
            'stream_network_access_details': 'streamNetworkAccessDetails',
            'source_type': 'sourceType',
            'secret_id': 'secretId',
            'camera_url': 'cameraUrl'
        }
        self._stream_network_access_details = None
        self._source_type = None
        self._secret_id = None
        self._camera_url = None
        self._source_type = 'RTSP'

    @property
    def secret_id(self):
        """
        Gets the secret_id of this RtspSourceDetails.
        `OCID`__ of secret where credentials are stored in username:password format.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The secret_id of this RtspSourceDetails.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """
        Sets the secret_id of this RtspSourceDetails.
        `OCID`__ of secret where credentials are stored in username:password format.

        __ https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param secret_id: The secret_id of this RtspSourceDetails.
        :type: str
        """
        self._secret_id = secret_id

    @property
    def camera_url(self):
        """
        **[Required]** Gets the camera_url of this RtspSourceDetails.
        url of camera


        :return: The camera_url of this RtspSourceDetails.
        :rtype: str
        """
        return self._camera_url

    @camera_url.setter
    def camera_url(self, camera_url):
        """
        Sets the camera_url of this RtspSourceDetails.
        url of camera


        :param camera_url: The camera_url of this RtspSourceDetails.
        :type: str
        """
        self._camera_url = camera_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .field_value import FieldValue
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ValueString(FieldValue):
    """
    The string field value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ValueString object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.ValueString.value_type` attribute
        of this class is ``STRING`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value_type:
            The value to assign to the value_type property of this ValueString.
            Allowed values for this property are: "STRING", "DATE", "TIME", "PHONE_NUMBER", "NUMBER", "INTEGER", "ARRAY"
        :type value_type: str

        :param text:
            The value to assign to the text property of this ValueString.
        :type text: str

        :param confidence:
            The value to assign to the confidence property of this ValueString.
        :type confidence: float

        :param bounding_polygon:
            The value to assign to the bounding_polygon property of this ValueString.
        :type bounding_polygon: oci.ai_vision.models.BoundingPolygon

        :param word_indexes:
            The value to assign to the word_indexes property of this ValueString.
        :type word_indexes: list[int]

        :param value:
            The value to assign to the value property of this ValueString.
        :type value: str

        """
        self.swagger_types = {
            'value_type': 'str',
            'text': 'str',
            'confidence': 'float',
            'bounding_polygon': 'BoundingPolygon',
            'word_indexes': 'list[int]',
            'value': 'str'
        }
        self.attribute_map = {
            'value_type': 'valueType',
            'text': 'text',
            'confidence': 'confidence',
            'bounding_polygon': 'boundingPolygon',
            'word_indexes': 'wordIndexes',
            'value': 'value'
        }
        self._value_type = None
        self._text = None
        self._confidence = None
        self._bounding_polygon = None
        self._word_indexes = None
        self._value = None
        self._value_type = 'STRING'

    @property
    def value(self):
        """
        **[Required]** Gets the value of this ValueString.
        The string text.


        :return: The value of this ValueString.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ValueString.
        The string text.


        :param value: The value of this ValueString.
        :type: str
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnalyzeVideoResult(object):
    """
    Video analysis results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnalyzeVideoResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param video_metadata:
            The value to assign to the video_metadata property of this AnalyzeVideoResult.
        :type video_metadata: oci.ai_vision.models.VideoMetadata

        :param video_labels:
            The value to assign to the video_labels property of this AnalyzeVideoResult.
        :type video_labels: list[oci.ai_vision.models.VideoLabel]

        :param video_objects:
            The value to assign to the video_objects property of this AnalyzeVideoResult.
        :type video_objects: list[oci.ai_vision.models.VideoObject]

        :param video_tracked_objects:
            The value to assign to the video_tracked_objects property of this AnalyzeVideoResult.
        :type video_tracked_objects: list[oci.ai_vision.models.VideoTrackedObject]

        :param video_text:
            The value to assign to the video_text property of this AnalyzeVideoResult.
        :type video_text: list[oci.ai_vision.models.VideoText]

        :param video_faces:
            The value to assign to the video_faces property of this AnalyzeVideoResult.
        :type video_faces: list[oci.ai_vision.models.VideoFace]

        :param ontology_classes:
            The value to assign to the ontology_classes property of this AnalyzeVideoResult.
        :type ontology_classes: list[oci.ai_vision.models.OntologyClass]

        :param label_detection_model_version:
            The value to assign to the label_detection_model_version property of this AnalyzeVideoResult.
        :type label_detection_model_version: str

        :param object_detection_model_version:
            The value to assign to the object_detection_model_version property of this AnalyzeVideoResult.
        :type object_detection_model_version: str

        :param object_tracking_model_version:
            The value to assign to the object_tracking_model_version property of this AnalyzeVideoResult.
        :type object_tracking_model_version: str

        :param text_detection_model_version:
            The value to assign to the text_detection_model_version property of this AnalyzeVideoResult.
        :type text_detection_model_version: str

        :param face_detection_model_version:
            The value to assign to the face_detection_model_version property of this AnalyzeVideoResult.
        :type face_detection_model_version: str

        :param errors:
            The value to assign to the errors property of this AnalyzeVideoResult.
        :type errors: list[oci.ai_vision.models.ProcessingError]

        """
        self.swagger_types = {
            'video_metadata': 'VideoMetadata',
            'video_labels': 'list[VideoLabel]',
            'video_objects': 'list[VideoObject]',
            'video_tracked_objects': 'list[VideoTrackedObject]',
            'video_text': 'list[VideoText]',
            'video_faces': 'list[VideoFace]',
            'ontology_classes': 'list[OntologyClass]',
            'label_detection_model_version': 'str',
            'object_detection_model_version': 'str',
            'object_tracking_model_version': 'str',
            'text_detection_model_version': 'str',
            'face_detection_model_version': 'str',
            'errors': 'list[ProcessingError]'
        }
        self.attribute_map = {
            'video_metadata': 'videoMetadata',
            'video_labels': 'videoLabels',
            'video_objects': 'videoObjects',
            'video_tracked_objects': 'videoTrackedObjects',
            'video_text': 'videoText',
            'video_faces': 'videoFaces',
            'ontology_classes': 'ontologyClasses',
            'label_detection_model_version': 'labelDetectionModelVersion',
            'object_detection_model_version': 'objectDetectionModelVersion',
            'object_tracking_model_version': 'objectTrackingModelVersion',
            'text_detection_model_version': 'textDetectionModelVersion',
            'face_detection_model_version': 'faceDetectionModelVersion',
            'errors': 'errors'
        }
        self._video_metadata = None
        self._video_labels = None
        self._video_objects = None
        self._video_tracked_objects = None
        self._video_text = None
        self._video_faces = None
        self._ontology_classes = None
        self._label_detection_model_version = None
        self._object_detection_model_version = None
        self._object_tracking_model_version = None
        self._text_detection_model_version = None
        self._face_detection_model_version = None
        self._errors = None

    @property
    def video_metadata(self):
        """
        **[Required]** Gets the video_metadata of this AnalyzeVideoResult.

        :return: The video_metadata of this AnalyzeVideoResult.
        :rtype: oci.ai_vision.models.VideoMetadata
        """
        return self._video_metadata

    @video_metadata.setter
    def video_metadata(self, video_metadata):
        """
        Sets the video_metadata of this AnalyzeVideoResult.

        :param video_metadata: The video_metadata of this AnalyzeVideoResult.
        :type: oci.ai_vision.models.VideoMetadata
        """
        self._video_metadata = video_metadata

    @property
    def video_labels(self):
        """
        Gets the video_labels of this AnalyzeVideoResult.
        Detected labels in a video.


        :return: The video_labels of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.VideoLabel]
        """
        return self._video_labels

    @video_labels.setter
    def video_labels(self, video_labels):
        """
        Sets the video_labels of this AnalyzeVideoResult.
        Detected labels in a video.


        :param video_labels: The video_labels of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.VideoLabel]
        """
        self._video_labels = video_labels

    @property
    def video_objects(self):
        """
        Gets the video_objects of this AnalyzeVideoResult.
        Detected objects in a video.


        :return: The video_objects of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.VideoObject]
        """
        return self._video_objects

    @video_objects.setter
    def video_objects(self, video_objects):
        """
        Sets the video_objects of this AnalyzeVideoResult.
        Detected objects in a video.


        :param video_objects: The video_objects of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.VideoObject]
        """
        self._video_objects = video_objects

    @property
    def video_tracked_objects(self):
        """
        Gets the video_tracked_objects of this AnalyzeVideoResult.
        Tracked objects in a video.


        :return: The video_tracked_objects of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.VideoTrackedObject]
        """
        return self._video_tracked_objects

    @video_tracked_objects.setter
    def video_tracked_objects(self, video_tracked_objects):
        """
        Sets the video_tracked_objects of this AnalyzeVideoResult.
        Tracked objects in a video.


        :param video_tracked_objects: The video_tracked_objects of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.VideoTrackedObject]
        """
        self._video_tracked_objects = video_tracked_objects

    @property
    def video_text(self):
        """
        Gets the video_text of this AnalyzeVideoResult.
        Detected text in a video.


        :return: The video_text of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.VideoText]
        """
        return self._video_text

    @video_text.setter
    def video_text(self, video_text):
        """
        Sets the video_text of this AnalyzeVideoResult.
        Detected text in a video.


        :param video_text: The video_text of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.VideoText]
        """
        self._video_text = video_text

    @property
    def video_faces(self):
        """
        Gets the video_faces of this AnalyzeVideoResult.
        Detected faces in a video.


        :return: The video_faces of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.VideoFace]
        """
        return self._video_faces

    @video_faces.setter
    def video_faces(self, video_faces):
        """
        Sets the video_faces of this AnalyzeVideoResult.
        Detected faces in a video.


        :param video_faces: The video_faces of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.VideoFace]
        """
        self._video_faces = video_faces

    @property
    def ontology_classes(self):
        """
        Gets the ontology_classes of this AnalyzeVideoResult.
        The ontologyClasses of video labels.


        :return: The ontology_classes of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.OntologyClass]
        """
        return self._ontology_classes

    @ontology_classes.setter
    def ontology_classes(self, ontology_classes):
        """
        Sets the ontology_classes of this AnalyzeVideoResult.
        The ontologyClasses of video labels.


        :param ontology_classes: The ontology_classes of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.OntologyClass]
        """
        self._ontology_classes = ontology_classes

    @property
    def label_detection_model_version(self):
        """
        Gets the label_detection_model_version of this AnalyzeVideoResult.
        Label Detection model version.


        :return: The label_detection_model_version of this AnalyzeVideoResult.
        :rtype: str
        """
        return self._label_detection_model_version

    @label_detection_model_version.setter
    def label_detection_model_version(self, label_detection_model_version):
        """
        Sets the label_detection_model_version of this AnalyzeVideoResult.
        Label Detection model version.


        :param label_detection_model_version: The label_detection_model_version of this AnalyzeVideoResult.
        :type: str
        """
        self._label_detection_model_version = label_detection_model_version

    @property
    def object_detection_model_version(self):
        """
        Gets the object_detection_model_version of this AnalyzeVideoResult.
        Object Detection model version.


        :return: The object_detection_model_version of this AnalyzeVideoResult.
        :rtype: str
        """
        return self._object_detection_model_version

    @object_detection_model_version.setter
    def object_detection_model_version(self, object_detection_model_version):
        """
        Sets the object_detection_model_version of this AnalyzeVideoResult.
        Object Detection model version.


        :param object_detection_model_version: The object_detection_model_version of this AnalyzeVideoResult.
        :type: str
        """
        self._object_detection_model_version = object_detection_model_version

    @property
    def object_tracking_model_version(self):
        """
        Gets the object_tracking_model_version of this AnalyzeVideoResult.
        Object Tracking model version.


        :return: The object_tracking_model_version of this AnalyzeVideoResult.
        :rtype: str
        """
        return self._object_tracking_model_version

    @object_tracking_model_version.setter
    def object_tracking_model_version(self, object_tracking_model_version):
        """
        Sets the object_tracking_model_version of this AnalyzeVideoResult.
        Object Tracking model version.


        :param object_tracking_model_version: The object_tracking_model_version of this AnalyzeVideoResult.
        :type: str
        """
        self._object_tracking_model_version = object_tracking_model_version

    @property
    def text_detection_model_version(self):
        """
        Gets the text_detection_model_version of this AnalyzeVideoResult.
        Text Detection model version.


        :return: The text_detection_model_version of this AnalyzeVideoResult.
        :rtype: str
        """
        return self._text_detection_model_version

    @text_detection_model_version.setter
    def text_detection_model_version(self, text_detection_model_version):
        """
        Sets the text_detection_model_version of this AnalyzeVideoResult.
        Text Detection model version.


        :param text_detection_model_version: The text_detection_model_version of this AnalyzeVideoResult.
        :type: str
        """
        self._text_detection_model_version = text_detection_model_version

    @property
    def face_detection_model_version(self):
        """
        Gets the face_detection_model_version of this AnalyzeVideoResult.
        Face Detection model version.


        :return: The face_detection_model_version of this AnalyzeVideoResult.
        :rtype: str
        """
        return self._face_detection_model_version

    @face_detection_model_version.setter
    def face_detection_model_version(self, face_detection_model_version):
        """
        Sets the face_detection_model_version of this AnalyzeVideoResult.
        Face Detection model version.


        :param face_detection_model_version: The face_detection_model_version of this AnalyzeVideoResult.
        :type: str
        """
        self._face_detection_model_version = face_detection_model_version

    @property
    def errors(self):
        """
        Gets the errors of this AnalyzeVideoResult.
        Array of possible errors.


        :return: The errors of this AnalyzeVideoResult.
        :rtype: list[oci.ai_vision.models.ProcessingError]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this AnalyzeVideoResult.
        Array of possible errors.


        :param errors: The errors of this AnalyzeVideoResult.
        :type: list[oci.ai_vision.models.ProcessingError]
        """
        self._errors = errors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoTextSegment(object):
    """
    A text segment in a video.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoTextSegment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param video_segment:
            The value to assign to the video_segment property of this VideoTextSegment.
        :type video_segment: oci.ai_vision.models.VideoSegment

        :param confidence:
            The value to assign to the confidence property of this VideoTextSegment.
        :type confidence: float

        :param frames:
            The value to assign to the frames property of this VideoTextSegment.
        :type frames: list[oci.ai_vision.models.VideoTextFrame]

        """
        self.swagger_types = {
            'video_segment': 'VideoSegment',
            'confidence': 'float',
            'frames': 'list[VideoTextFrame]'
        }
        self.attribute_map = {
            'video_segment': 'videoSegment',
            'confidence': 'confidence',
            'frames': 'frames'
        }
        self._video_segment = None
        self._confidence = None
        self._frames = None

    @property
    def video_segment(self):
        """
        **[Required]** Gets the video_segment of this VideoTextSegment.

        :return: The video_segment of this VideoTextSegment.
        :rtype: oci.ai_vision.models.VideoSegment
        """
        return self._video_segment

    @video_segment.setter
    def video_segment(self, video_segment):
        """
        Sets the video_segment of this VideoTextSegment.

        :param video_segment: The video_segment of this VideoTextSegment.
        :type: oci.ai_vision.models.VideoSegment
        """
        self._video_segment = video_segment

    @property
    def confidence(self):
        """
        **[Required]** Gets the confidence of this VideoTextSegment.
        The confidence score, between 0 and 1.


        :return: The confidence of this VideoTextSegment.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this VideoTextSegment.
        The confidence score, between 0 and 1.


        :param confidence: The confidence of this VideoTextSegment.
        :type: float
        """
        self._confidence = confidence

    @property
    def frames(self):
        """
        **[Required]** Gets the frames of this VideoTextSegment.
        Text frame in a segment.


        :return: The frames of this VideoTextSegment.
        :rtype: list[oci.ai_vision.models.VideoTextFrame]
        """
        return self._frames

    @frames.setter
    def frames(self, frames):
        """
        Sets the frames of this VideoTextSegment.
        Text frame in a segment.


        :param frames: The frames of this VideoTextSegment.
        :type: list[oci.ai_vision.models.VideoTextFrame]
        """
        self._frames = frames

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VideoTrackedObjectProperties(object):
    """
    Properties of a tracked object in a video.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VideoTrackedObjectProperties object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param axle_count:
            The value to assign to the axle_count property of this VideoTrackedObjectProperties.
        :type axle_count: int

        :param trailer_ids:
            The value to assign to the trailer_ids property of this VideoTrackedObjectProperties.
        :type trailer_ids: list[int]

        """
        self.swagger_types = {
            'axle_count': 'int',
            'trailer_ids': 'list[int]'
        }
        self.attribute_map = {
            'axle_count': 'axleCount',
            'trailer_ids': 'trailerIds'
        }
        self._axle_count = None
        self._trailer_ids = None

    @property
    def axle_count(self):
        """
        Gets the axle_count of this VideoTrackedObjectProperties.
        The axle count value of a tracked vehicle.


        :return: The axle_count of this VideoTrackedObjectProperties.
        :rtype: int
        """
        return self._axle_count

    @axle_count.setter
    def axle_count(self, axle_count):
        """
        Sets the axle_count of this VideoTrackedObjectProperties.
        The axle count value of a tracked vehicle.


        :param axle_count: The axle_count of this VideoTrackedObjectProperties.
        :type: int
        """
        self._axle_count = axle_count

    @property
    def trailer_ids(self):
        """
        Gets the trailer_ids of this VideoTrackedObjectProperties.
        Object IDs of the trailers associated with the tracked vehicle.


        :return: The trailer_ids of this VideoTrackedObjectProperties.
        :rtype: list[int]
        """
        return self._trailer_ids

    @trailer_ids.setter
    def trailer_ids(self, trailer_ids):
        """
        Sets the trailer_ids of this VideoTrackedObjectProperties.
        Object IDs of the trailers associated with the tracked vehicle.


        :param trailer_ids: The trailer_ids of this VideoTrackedObjectProperties.
        :type: list[int]
        """
        self._trailer_ids = trailer_ids

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModelVersionDetails(object):
    """
    Model version for object detection/tracking.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ModelVersionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param objects:
            The value to assign to the objects property of this ModelVersionDetails.
        :type objects: list[str]

        :param model_version:
            The value to assign to the model_version property of this ModelVersionDetails.
        :type model_version: str

        """
        self.swagger_types = {
            'objects': 'list[str]',
            'model_version': 'str'
        }
        self.attribute_map = {
            'objects': 'objects',
            'model_version': 'modelVersion'
        }
        self._objects = None
        self._model_version = None

    @property
    def objects(self):
        """
        **[Required]** Gets the objects of this ModelVersionDetails.
        List of the object category labels.


        :return: The objects of this ModelVersionDetails.
        :rtype: list[str]
        """
        return self._objects

    @objects.setter
    def objects(self, objects):
        """
        Sets the objects of this ModelVersionDetails.
        List of the object category labels.


        :param objects: The objects of this ModelVersionDetails.
        :type: list[str]
        """
        self._objects = objects

    @property
    def model_version(self):
        """
        **[Required]** Gets the model_version of this ModelVersionDetails.
        Model version or ocid


        :return: The model_version of this ModelVersionDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this ModelVersionDetails.
        Model version or ocid


        :param model_version: The model_version of this ModelVersionDetails.
        :type: str
        """
        self._model_version = model_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from .document_feature import DocumentFeature
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DocumentTextDetectionFeature(DocumentFeature):
    """
    Text recognition
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DocumentTextDetectionFeature object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_vision.models.DocumentTextDetectionFeature.feature_type` attribute
        of this class is ``TEXT_DETECTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param feature_type:
            The value to assign to the feature_type property of this DocumentTextDetectionFeature.
            Allowed values for this property are: "LANGUAGE_CLASSIFICATION", "TEXT_DETECTION", "TABLE_DETECTION", "KEY_VALUE_DETECTION", "DOCUMENT_CLASSIFICATION"
        :type feature_type: str

        :param generate_searchable_pdf:
            The value to assign to the generate_searchable_pdf property of this DocumentTextDetectionFeature.
        :type generate_searchable_pdf: bool

        """
        self.swagger_types = {
            'feature_type': 'str',
            'generate_searchable_pdf': 'bool'
        }
        self.attribute_map = {
            'feature_type': 'featureType',
            'generate_searchable_pdf': 'generateSearchablePdf'
        }
        self._feature_type = None
        self._generate_searchable_pdf = None
        self._feature_type = 'TEXT_DETECTION'

    @property
    def generate_searchable_pdf(self):
        """
        Gets the generate_searchable_pdf of this DocumentTextDetectionFeature.
        Whether or not to generate a searchable PDF file.


        :return: The generate_searchable_pdf of this DocumentTextDetectionFeature.
        :rtype: bool
        """
        return self._generate_searchable_pdf

    @generate_searchable_pdf.setter
    def generate_searchable_pdf(self, generate_searchable_pdf):
        """
        Sets the generate_searchable_pdf of this DocumentTextDetectionFeature.
        Whether or not to generate a searchable PDF file.


        :param generate_searchable_pdf: The generate_searchable_pdf of this DocumentTextDetectionFeature.
        :type: bool
        """
        self._generate_searchable_pdf = generate_searchable_pdf

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
